@@ -83,8 +83,11 @@ try:
     from pandas.errors import PerformanceWarning
 except ImportError:
     from pandas.core.common import PerformanceWarning
-from pandas.io.common import get_filepath_or_buffer
-from pandas.core.internals import BlockManager, make_block, _safe_reshape
+try:
+    from pandas.io.common import get_filepath_or_buffer
+except ImportError:
+    from pandas.io.common import _get_filepath_or_buffer as get_filepath_or_buffer
+from pandas.core.internals import BlockManager, make_block
 import pandas.core.internals as internals
 
 from mbf_pandas_msgpack import _is_pandas_legacy_version
@@ -94,6 +97,35 @@ from mbf_pandas_msgpack._move import (
     move_into_mutable_buffer as _move_into_mutable_buffer,
 )
 
+
+from pandas.core.dtypes.common import is_extension_array_dtype
+from pandas.core.dtypes.generic import (
+    ABCSeries,
+)
+
+# from old pandas.core.internals.blocks
+def _safe_reshape(arr, new_shape):
+    """
+    If possible, reshape `arr` to have shape `new_shape`,
+    with a couple of exceptions (see gh-13012):
+    1) If `arr` is a ExtensionArray or Index, `arr` will be
+       returned as is.
+    2) If `arr` is a Series, the `_values` attribute will
+       be reshaped and returned.
+    Parameters
+    ----------
+    arr : array-like, object to be reshaped
+    new_shape : int or tuple of ints, the new shape
+    """
+    if isinstance(arr, ABCSeries):
+        arr = arr._values
+    if not is_extension_array_dtype(arr.dtype):
+        # Note: this will include TimedeltaArray and tz-naive DatetimeArray
+        # TODO(EA2D): special case will be unnecessary with 2D EAs
+        arr = np.asarray(arr).reshape(new_shape)
+    return arr
+
+
 NaTType = type(NaT)
 
 # check which compression libs we have installed
@@ -207,7 +239,11 @@ def read_msgpack(path_or_buf, encoding="utf-8", iterator=False, **kwargs):
     obj : type of object stored in file
 
     """
-    path_or_buf, *_ = get_filepath_or_buffer(path_or_buf)
+    path_or_buf = get_filepath_or_buffer(path_or_buf)
+    if hasattr(path_or_buf, 'filepath_or_buffer'):
+        path_or_buf = path_or_buf.filepath_or_buffer
+    else:
+        path_or_buf = path_or_buf[0]
     if iterator:
         return Iterator(path_or_buf)
 
